// Copyright (C) 2016 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0

#ifndef TESTEXTRAINCLUDE_H
#define TESTEXTRAINCLUDE_H

#include <QtCore/qobject.h>

class TestExtraInclude : public QObject
{
    Q_OBJECT
    private slots:
        void testClassExtraInclude();
        void testGlobalExtraIncludes();
};

#endif
